# Outras Formas de Utilização

O arquivo _.csv_ disponível no pacote foi atualizado em 2026. Fica disponível no endereço a seguir

- <a href="https://raw.githubusercontent.com/michelmetran/ufesp/refs/heads/main/ufesp/data/ufesp.csv" target="_blank">https://raw.githubusercontent.com/michelmetran/ufesp/refs/heads/main/ufesp/data/ufesp.csv</a>

<br>

---

## _Google Spreadsheets_

Uma vez que o arquivo _.csv_ está disponível em um servidor, é possível utilizar a função **_=IMPORTDATA()_** do _Google Spreadsheets_ para acessa-lo diretamente na tabela, possibilitando cálculos etc.

![Google Sheets](../assets/gsheets.png)

<br>

---

## _Microsoft Excel_

No _Microsoft Excel_ é possível também manter o arquivo atualizado em uma aba, por meio dos passos abaixo:

![Excel](../assets/excel.gif)

<br>

---

## Outros Formatos

É possível também acessar a tabela em formatos _.csv_ nos botões abaixo:

<a href="https://raw.githubusercontent.com/michelmetran/ufesp/refs/heads/main/ufesp/data/ufesp.csv" class="btn btn--primary">Download _csv_</a>
